# spec file for package libzen
#
# Copyright (c) 2017 SUSE LINUX GmbH, Nuernberg, Germany.
# Copyright (c) 2008-2010 oc2pus
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%define sover	0
Name:           libzen
Version:        0.4.31
Release:        1.1
Summary:        C++ utility library
License:        Zlib
Group:          Development/Libraries/C and C++
Url:            http://zenlib.sourceforge.net/
Source:         https://prdownloads.sourceforge.net/zenlib/libzen_%{version}.tar.bz2
Source1:        baselibs.conf
BuildRequires:  doxygen
BuildRequires:  fdupes
BuildRequires:  gcc-c++
BuildRequires:  libtool
BuildRequires:  pkgconfig
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
ZenLib is a C++ utility library. It includes classes for handling
strings, configuration, bit streams, threading, translation
and cross-platform operating system functions.

%package -n %{name}%{sover}
Summary:        The ZenLib C++ utility library
Group:          System/Libraries

%description -n %{name}%{sover}
ZenLib is a C++ utility library. It includes classes for handling
strings, configuration, bit streams, threading, translation
and cross-platform operating system functions.

%package -n libzen-devel
Summary:        Include files to develop for %{name}
Group:          Development/Libraries/C and C++
Requires:       %{name}%{sover} = %{version}

%description -n libzen-devel
Include files and mandatory libraries to develop
for %{name}.

%prep
%setup -q -n ZenLib
sed -i 's/\r$//' *.txt Source/Doc/*.html
chmod 644 *.txt Source/Doc/*.html

%build
# generate docs
pushd Source/Doc
    doxygen -u 2> /dev/null
    doxygen Doxyfile
popd

pushd Project/GNU/Library
    chmod +x autogen
    NOCONFIGURE=1 ./autogen
    %configure --enable-shared --disable-static
    make %{?_smp_mflags}
popd

%install
pushd Project/GNU/Library
%make_install
popd

# Zenlib headers and ZenLib-config
install -dm 755 %{buildroot}%{_includedir}/ZenLib
install -m 644 Source/ZenLib/*.h \
    %{buildroot}%{_includedir}/ZenLib
for i in HTTP_Client Format/Html Format/Http; do
    install -dm 755 %{buildroot}%{_includedir}/ZenLib/$i
    install -m 644 Source/ZenLib/$i/*.h \
    	%{buildroot}%{_includedir}/ZenLib/$i
done

sed -i -e 's|Version: |Version: %{version}|g' \
    Project/GNU/Library/libzen.pc
install -dm 755 %{buildroot}%{_libdir}/pkgconfig
install -m 644 Project/GNU/Library/libzen.pc \
    %{buildroot}%{_libdir}/pkgconfig

rm %{buildroot}%{_libdir}/libzen.la

# we don't need libzen-config
rm %{buildroot}%{_bindir}/libzen-config

%fdupes %{buildroot}/%{_prefix}

%post   -n %{name}%{sover} -p /sbin/ldconfig
%postun -n %{name}%{sover} -p /sbin/ldconfig

%files -n %{name}%{sover}
%defattr(-,root,root,-)
%doc *.txt
%{_libdir}/libzen.so.%{sover}
%{_libdir}/libzen.so.%{sover}.*

%files -n libzen-devel
%defattr(-,root,root,-)
%doc Source/Doc/Documentation.html
%doc Doc/*
%{_includedir}/ZenLib/
%{_libdir}/libzen.so
%{_libdir}/pkgconfig/*.pc

%changelog
* Sat Mar  4 2017 jengelh@inai.de
- Rename %%soname to %%sover to reflects its actual use.
- Drop export CFLAGS because %%configure does that already.
- Use --disable-static in place of building and later removing .a.
- Limit scope of %%fdupes to partition.
- Clean up descriptions.
* Sun Feb 26 2017 aloisio@gmx.com
- Added baselibs.conf as source file
* Sun Feb 26 2017 davejplater@gmail.com
- Relicensed to Zlib following Fedora.
* Sun Feb 26 2017 aloisio@gmx.com
- Update to version 0.4.31
  * BigEndian2float16() was buggy
  * <new> is possible only with C++
  version 0.4.30
  * New MemoryUtils.h functions for SSE2 memcpy
  * Ztring::From_Unicode(const wchar_t S)
  * CMake: scripts improvements, thanks to Ivan Romanov
- Spec cleanup
* Thu Mar 27 2014 i@margueirte.su
- update version 0.4.29
  * Ztring: Ztring_NoZero option was not correctly implemented
  * File: Write only is not possible with ios_base::out (file is
    truncated) on Linux
  * Dir: Include_Dirs only was not working
  * File: accepts Windows "\\?\" magic value
* Thu Oct  4 2012 i@marguerite.su  
- Update to 0.4.28
  * Removing _T() in order to be compatible with LLVM compiler
  * Ztring: UTF-16 conversion routines crash if the provided string size is odd.
  * GNU: forcing stdc++ at link
* Sat May 19 2012 seife+obs@b1-systems.com
- add autoconf/automake/libtool to buildrequires to fix 12.2 build
* Tue Oct 18 2011 nomail@nomail.com
- Update to 0.4.22
  x #3412495, Ztring: To_UTF8() was working wrong, corrected
    thanks to Andrew Jang
  x #3157308, Ztring::Assign_FromFile(): Memory leak
  + TinyXml updated
  + float16 (on disk) support
  + Ztring: more compatibility with uCLibC
  x BitStream_LE: wrong result if buffer underrun
  + HTTP helpers in Unicode version
  x BitStream Little Endian: count of remaining bits was wrong
  x ZtringList and ZtringListList :: Read(): do not remove pending
    delimiters
  x File Open status: error with Windows return value
* Tue Mar  8 2011 pascal.bleser@opensuse.org
- add baselibs.conf
- update to 0.4.17:
  * BitStream: skip methods improvements
- changes from 0.4.16:
  * BitStream: Peek3()
  * decimal point issues with some specific compilers/OS
  * ZtringList: issues with EOL
  * #3025205, file is not opened if a "?" is in it
* Sat Jul 31 2010 toni@links2linux.de
- update to 0.4.15
* Mon May  3 2010 toni@links2linux.de
- update to 0.4.14
* Fri Apr 16 2010 toni@links2linux.de
- update to 0.4.13
* Tue Mar  9 2010 toni@links2linux.de
- update to 0.4.12
* Sun Feb 21 2010 toni@links2linux.de
- update to 0.4.11
* Mon Jan 11 2010 toni@links2linux.de
- update to 0.4.10
* Fri Nov 20 2009 toni@links2linux.de
- update to 0.4.9
* Fri Oct 30 2009 toni@links2linux.de
- update to 0.4.8
* Tue Oct 27 2009 toni@links2linux.de
- update to 0.4.7
* Tue Oct 13 2009 toni@links2linux.de
- update to 0.4.6
* Fri Apr 17 2009 toni@links2linux.de
- update to 0.4.2
* Sun Apr  5 2009 toni@links2linux.de
- update to 0.4.1
* Sat Apr  4 2009 toni@links2linux.de
- redowngrade to 0.4.0
* Thu Apr  2 2009 toni@links2linux.de
- update to 0.4.1
* Fri Mar 20 2009 toni@links2linux.de
- update to 0.4.0
* Fri Feb 13 2009 toni@links2linux.de
- update to 0.3.8
* Fri Jan 30 2009 toni@links2linux.de
- update to 0.3.7
* Fri Jan 23 2009 toni@links2linux.de
- update to 0.3.6
* Tue Dec  9 2008 toni@links2linux.de
- update to 0.3.5
- docs are now generated with doxygen
* Mon Nov 17 2008 toni@links2linux.de
- added api-doc to devel subpackage
- instead of ZenLib-config now a pkgconfig file is provided
* Mon Dec 10 2007 toni@links2linux.de
- libZenLib and libMediaInfoLib are renamed to libzen and libmediainfo
- install *-config files manually
- added devel-subpackages
- split off from MediaInfo package
